@@ -8,6 +8,7 @@ use RDF::Trine::Store::LDF;
 use RDF::Trine::Store;
 use RDF::Query;
 use Getopt::Long;
+use open qw(:utf8);
 
 use JSON ();
 my $JSON = JSON->new->utf8->allow_nonref;
@@ -36,8 +37,6 @@ EOF
     exit(1);
 }
 
-binmode(STDOUT,":encoding(UTF-8)");
-
 if (defined $sparql) {
     process_sparql($sparql);
 }
